==> source-highlight-2.1.2.tar.gz: source-highlight-2.1.2/src/lib/outlangdefparser.h <==
/* A Bison parser, made by GNU Bison 1.875d.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     BEGIN_T = 258,
     END_T = 259,
     DOC_TEMPLATE_T = 260,
     STYLE_TEMPLATE_T = 261,
     STYLE_SEPARATOR_T = 262,
     BOLD_T = 263,
     ITALICS_T = 264,
     UNDERLINE_T = 265,
     COLOR_T = 266,
     FIXED_T = 267,
     NOTFIXED_T = 268,
     COLORMAP_T = 269,
     DEFAULT_T = 270,
     ONESTYLE_T = 271,
     TRANSLATIONS_T = 272,
     EXTENSION_T = 273,
     ANCHOR_T = 274,
     KEY = 275,
     STRINGDEF = 276,
     REGEXDEF = 277
   };
#endif
#define BEGIN_T 258
#define END_T 259
#define DOC_TEMPLATE_T 260
#define STYLE_TEMPLATE_T 261
#define STYLE_SEPARATOR_T 262
#define BOLD_T 263
#define ITALICS_T 264
#define UNDERLINE_T 265
#define COLOR_T 266
#define FIXED_T 267
#define NOTFIXED_T 268
#define COLORMAP_T 269
#define DEFAULT_T 270
#define ONESTYLE_T 271
#define TRANSLATIONS_T 272
#define EXTENSION_T 273
#define ANCHOR_T 274
#define KEY 275
#define STRINGDEF 276
#define REGEXDEF 277




#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
#line 48 "./outlangdefparser.yy"
typedef union YYSTYPE {
  int tok ; /* command */
  bool booloption ;
  const std::string * string ; /* string : id, ... */
  int flag ;
} YYSTYPE;
/* Line 1285 of yacc.c.  */
#line 88 "outlangdefparser.h"
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif

extern YYSTYPE outlangdef_lval;

==> source-highlight-2.2.tar.gz: source-highlight-2.2/src/lib/outlangdefparser.h <==
/* A Bison parser, made by GNU Bison 1.875d.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     BEGIN_T = 258,
     END_T = 259,
     DOC_TEMPLATE_T = 260,
     STYLE_TEMPLATE_T = 261,
     STYLE_SEPARATOR_T = 262,
     BOLD_T = 263,
     ITALICS_T = 264,
     UNDERLINE_T = 265,
     COLOR_T = 266,
     FIXED_T = 267,
     NOTFIXED_T = 268,
     COLORMAP_T = 269,
     DEFAULT_T = 270,
     ONESTYLE_T = 271,
     TRANSLATIONS_T = 272,
     EXTENSION_T = 273,
     ANCHOR_T = 274,
     REFERENCE_T = 275,
     INLINE_REFERENCE_T = 276,
     POSTLINE_REFERENCE_T = 277,
     POSTDOC_REFERENCE_T = 278,
     KEY = 279,
     STRINGDEF = 280,
     REGEXDEF = 281,
     LINE_PREFIX_T = 282
   };
#endif
#define BEGIN_T 258
#define END_T 259
#define DOC_TEMPLATE_T 260
#define STYLE_TEMPLATE_T 261
#define STYLE_SEPARATOR_T 262
#define BOLD_T 263
#define ITALICS_T 264
#define UNDERLINE_T 265
#define COLOR_T 266
#define FIXED_T 267
#define NOTFIXED_T 268
#define COLORMAP_T 269
#define DEFAULT_T 270
#define ONESTYLE_T 271
#define TRANSLATIONS_T 272
#define EXTENSION_T 273
#define ANCHOR_T 274
#define REFERENCE_T 275
#define INLINE_REFERENCE_T 276
#define POSTLINE_REFERENCE_T 277
#define POSTDOC_REFERENCE_T 278
#define KEY 279
#define STRINGDEF 280
#define REGEXDEF 281
#define LINE_PREFIX_T 282




#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
#line 51 "./outlangdefparser.yy"
typedef union YYSTYPE {
  int tok ; /* command */
  bool booloption ;
  const std::string * string ; /* string : id, ... */
  int flag ;
} YYSTYPE;
/* Line 1285 of yacc.c.  */
#line 98 "outlangdefparser.h"
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif

extern YYSTYPE outlangdef_lval;
